==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/PingCore/src/com/clustercontrol/ping/core/PingCorePlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.core;

import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * pingƻ뵡ǽץ饰󥯥饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class PingCorePlugin extends AbstractUIPlugin {

    // ----- static ե ----- //

    /** ץ饰Υ󥹥 */
	private static PingCorePlugin plugin;
	
    //  ----- static ᥽å ----- //
    
    /**
     * ȤΥ󥹥󥹤֤ޤ
     * 
     * @return ȤΥ󥹥
     */
	public static PingCorePlugin getDefault() {
		return plugin;
	}

    /**
     * ץ饰Υ꥽Хɥꡢꤷʸ֤ޤ
     * 
     * @param key
     *            ʸ
     * @return ꤷʸ󡣥꥽Хɥ뤬̵硢⤷ϻꤷʸ ¸ߤʤϡkey֤ޤ
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /**
     * ץ饰Υ꥽Хɥꡢꤷʸ֤ޤ
     * <p>
     * 
     * @param key
     *            ʸ
     * @param arguments
     *            ֤ʸ
     * @return ꤷʸ󡣥꥽Хɥ뤬̵硢⤷ϻꤷʸ ¸ߤʤϡkey֤ޤ
     * @see java.text.MessageFormat
     */
    public static String getResourceString(String key, Object[] arguments) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            String message = (bundle != null) ? bundle.getString(key) : key;
            return MessageFormat.format(message, arguments);
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /*
     * ͥȤˤơ侩Ƥ᥽åɷǤ
     */

    /**
     * Ϥޤ
     * 
     * @param message
     *            åʸ
     * @param e
     *            ȯ㳰
     */
    public static void log(String message, Exception e) {
        IStatus status = new Status(IStatus.ERROR, getPluginId(),
                IStatus.ERROR, message, e);
        getDefault().getLog().log(status);
    }

    /**
     * Ϥޤ
     * 
     * @param message
     *            åʸ
     */
    public static void log(String message) {
        log(message, null);
    }

    /**
     * Ϥޤ
     * 
     * @param e
     *            ȯ㳰
     */
    public static void log(Exception e) {
        StringWriter stringWriter = new StringWriter();
        String message = stringWriter.getBuffer().toString();
        log(message, e);
    }

    /**
     * ץ饰IDȤѤǤ롢ͭID֤ޤ
     * 
     * @return ץ饰ID
     * @see Bundle#getSymbolicName()
     */
    public static String getPluginId() {
        return getDefault().getBundle().getSymbolicName();
    }

    // ----- instance ե ----- //

    /** ꥽Хɥ */
    private ResourceBundle resourceBundle = null;

    // ----- 󥹥ȥ饯 ----- //
    
    /**
     * 󥹥󥹤֤ޤ
     */
	public PingCorePlugin() {
		super();
		plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.ping.core.PingCorePluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
	}
	
    // ----- instance ᥽å ----- //

    /**
     * ץ饰γκݤ˸ƤФޤ
     * 
     * @param context
     *            BundleContext֥
     * @throws Exception
     *             㳰ȯ
     */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

    /**
     * ץ饰κݤ˸ƤФޤ
     * 
     * @param context
     *            BundleContext֥
     * @throws Exception
     *             㳰ȯ
     */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}
	
    /**
     * ץ饰ݻ꥽Хɥ֤ޤ
     * 
     * @return ꥽Хɥ
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/PingCore/src/com/clustercontrol/ping/core/PingCorePlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.core;

import java.io.StringWriter;
import java.text.MessageFormat;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;

/**
 * ping監視機能プラグインクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class PingCorePlugin extends AbstractUIPlugin {

    // ----- static フィールド ----- //

    /** プラグインのインスタンス */
	private static PingCorePlugin plugin;
	
    //  ----- static メソッド ----- //
    
    /**
     * 自身のインスタンスを返します。
     * 
     * @return 自身のインスタンス
     */
	public static PingCorePlugin getDefault() {
		return plugin;
	}

    /**
     * プラグインのリソースバンドルより、指定した文字列を返します。
     * 
     * @param key
     *            キー文字列
     * @return 指定した文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /**
     * プラグインのリソースバンドルより、指定した文字列を返します。
     * <p>
     * 
     * @param key
     *            キー文字列
     * @param arguments
     *            置き換える文字列
     * @return 指定した文字列。リソースバンドルが無い場合、もしくは指定した文字列 が存在しない場合は、keyを返します。
     * @see java.text.MessageFormat
     */
    public static String getResourceString(String key, Object[] arguments) {
        ResourceBundle bundle = getDefault().getResourceBundle();
        try {
            String message = (bundle != null) ? bundle.getString(key) : key;
            return MessageFormat.format(message, arguments);
        } catch (MissingResourceException e) {
            return key;
        }
    }
    
    /*
     * 参考サイトにて、実装を推奨していたメソッド群です。
     */

    /**
     * ログを出力します。
     * 
     * @param message
     *            ログメッセージ文字列
     * @param e
     *            発生した例外
     */
    public static void log(String message, Exception e) {
        IStatus status = new Status(IStatus.ERROR, getPluginId(),
                IStatus.ERROR, message, e);
        getDefault().getLog().log(status);
    }

    /**
     * ログを出力します。
     * 
     * @param message
     *            ログメッセージ文字列
     */
    public static void log(String message) {
        log(message, null);
    }

    /**
     * ログを出力します。
     * 
     * @param e
     *            発生した例外
     */
    public static void log(Exception e) {
        StringWriter stringWriter = new StringWriter();
        String message = stringWriter.getBuffer().toString();
        log(message, e);
    }

    /**
     * プラグインIDとして利用できる、固有のIDを返します。
     * 
     * @return プラグインID
     * @see Bundle#getSymbolicName()
     */
    public static String getPluginId() {
        return getDefault().getBundle().getSymbolicName();
    }

    // ----- instance フィールド ----- //

    /** リソースバンドル */
    private ResourceBundle resourceBundle = null;

    // ----- コンストラクタ ----- //
    
    /**
     * インスタンスを返します。
     */
	public PingCorePlugin() {
		super();
		plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.ping.core.PingCorePluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
	}
	
    // ----- instance メソッド ----- //

    /**
     * プラグインの活性化の際に呼ばれます。
     * 
     * @param context
     *            BundleContextオブジェクト
     * @throws Exception
     *             例外発生時
     */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

    /**
     * プラグインの非活性化の際に呼ばれます。
     * 
     * @param context
     *            BundleContextオブジェクト
     * @throws Exception
     *             例外発生時
     */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}
	
    /**
     * プラグインが保持するリソースバンドルを返します。
     * 
     * @return リソースバンドル
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}
